/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package chalk.tools.formats.ad;

import java.io.File;
import java.io.FileInputStream;
import java.nio.charset.Charset;

import chalk.tools.cmdline.ArgumentParser;
import chalk.tools.cmdline.CmdLineUtil;
import chalk.tools.cmdline.StreamFactoryRegistry;
import chalk.tools.cmdline.ArgumentParser.OptionalParameter;
import chalk.tools.cmdline.ArgumentParser.ParameterDescription;
import chalk.tools.formats.LanguageSampleStreamFactory;
import chalk.tools.sentdetect.SentenceSample;
import chalk.tools.util.ObjectStream;
import chalk.tools.util.PlainTextByLineStream;


/**
 * <b>Note:</b> Do not use this class, internal use only!
 */
public class ADSentenceSampleStreamFactory extends
    LanguageSampleStreamFactory<SentenceSample> {

  interface Parameters {
    @ParameterDescription(valueName = "charsetName", description = "encoding for reading and writing text.")
    Charset getEncoding();

    @ParameterDescription(valueName = "sampleData", description = "data to be used, usually a file name.")
    File getData();

    @ParameterDescription(valueName = "language", description = "language which is being processed.")
    String getLang();

    @ParameterDescription(valueName = "includeTitles", description = "if true will include sentences marked as headlines.")
    @OptionalParameter(defaultValue = "false")
    Boolean getIncludeTitles();
  }

  public static void registerFactory() {
    StreamFactoryRegistry.registerFactory(SentenceSample.class, "ad",
        new ADSentenceSampleStreamFactory(Parameters.class));
  }

  protected <P> ADSentenceSampleStreamFactory(Class<P> params) {
    super(params);
  }

  public ObjectStream<SentenceSample> create(String[] args) {

    Parameters params = ArgumentParser.parse(args, Parameters.class);

    language = params.getLang();

    boolean includeTitle = params.getIncludeTitles();

    FileInputStream sampleDataIn = CmdLineUtil.openInFile(params.getData());

    ObjectStream<String> lineStream = new PlainTextByLineStream(
        sampleDataIn.getChannel(), params.getEncoding());

    ADSentenceSampleStream sentenceStream = new ADSentenceSampleStream(
        lineStream, includeTitle);

    return sentenceStream;
  }

}
